@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Iterator::Rule;
 # ABSTRACT: Iterative, recursive file finder
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 # Register warnings category
 use warnings::register;
@@ -564,7 +564,7 @@ Path::Iterator::Rule - Iterative, recursive file finder
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -705,12 +705,12 @@ The default is slow, but safe.
 
 The C<error_handler> parameter must be a subroutine reference.  It will be
 called when a rule test throws an exception.  The first argument will be
-the L<Path::Class> object being inspected and the second argument will be
+the file name being inspected and the second argument will be
 the exception.
 
 The paths inspected and returned will be relative to the search directories
-provided.  If these are absolute, then the objects returned will have absolute
-paths.  If these are relative, then the objects returned will have relative
+provided.  If these are absolute, then the paths returned will have absolute
+paths.  If these are relative, then the paths returned will have relative
 paths.
 
 =head3 C<iter_fast>
@@ -735,7 +735,7 @@ the consequences.  See L</PERFORMANCE> for details.
 
 =head3 C<test>
 
-  if ( $rule->test( $path ) ) { ... }
+  if ( $rule->test( $path, $basename, $stash ) ) { ... }
 
 Test a file path against a rule.  Used internally, but provided should
 someone want to create their own, custom iteration algorithm.
@@ -947,8 +947,7 @@ correct behavior.
   $rule->not_dangling;
 
 The C<dangling> rule method matches dangling symlinks.  Use it or its inverse
-to control how dangling symlinks should be treated.  Note that a dangling
-symlink will be returned by the iterator as a L<Path::Class::File> object.
+to control how dangling symlinks should be treated.
 
 =head3 C<shebang>
 
@@ -973,7 +972,7 @@ version.
 
 =head2 Custom rule subroutines
 
-Rules are implemented as (usually anonymous) subroutines callbacks that return
+Rules are implemented as (usually anonymous) subroutine callbacks that return
 a value indicating whether or not the rule matches.  These callbacks are called
 with three arguments.  The first argument is a path, which is
 also locally aliased as the C<$_> global variable for convenience in simple
@@ -1090,14 +1089,15 @@ _children -- given a directory, return an (unsorted) list of [ basename, full pa
 
 =back
 
-Note that C<_children> should return a I<list> of I<tuples>, where the tuples are basename and full path.
+Note that C<_children> should return a I<list> of I<tuples>, where the tuples
+are array references containing basename and full path.
 
 See L<Path::Class::Rule> source for an example.
 
 =head1 LEXICAL WARNINGS
 
 If you run with lexical warnings enabled, C<Path::Iterator::Rule> will issue
-warnings in certain circumstances (such as a read-only directory that must be
+warnings in certain circumstances (such as an unreadable directory that must be
 skipped).  To disable these categories, put the following statement at the
 correct scope:
 
@@ -1183,6 +1183,11 @@ There are many other file finding modules out there.  They all have various
 features/deficiencies, depending on your preferences and needs.  Here is an
 (incomplete) list of alternatives, with some comparison commentary.
 
+L<Path::Class::Rule> and L<IO::All::Rule> are subclasses of
+C<Path::Iterator::Rule> and operate on L<Path::Class> and L<IO::All> objects,
+respectively.  Because of this, they are substantially slower on
+large directory trees than just using this module directly.
+
 L<File::Find> is part of the Perl core.  It requires the user to write a
 callback function to process each node of the search.  Callbacks must use
 global variables to determine the current node.  It only supports depth-first
